@@ -45,8 +45,8 @@ if TYPE_CHECKING:
 
     from acp.agent.protocol import Agent
     from acp.connection import StreamObserver
-    from acp.meta import AgentMethod
     from acp.schema import (
+        AgentMethod,
         CreateTerminalRequest,
         InitializeResponse,
         KillTerminalCommandRequest,
@@ -94,7 +94,7 @@ class AgentSideConnection(Client):
         )
 
     # client-bound methods (agent -> client)
-    async def session_update(self, params: SessionNotification) -> None:
+    async def session_update(self, params: SessionNotification[Any]) -> None:
         dct = params.model_dump(by_alias=True, exclude_none=True)
         await self._conn.send_notification("session/update", dct)
 
@@ -214,11 +214,10 @@ async def _agent_handler(  # noqa: PLR0911
             p = AuthenticateRequest.model_validate(params)
             result = await agent.authenticate(p)
             return result.model_dump(by_alias=True, exclude_none=True) if result else {}
-        case _ if method.startswith("_"):
-            ext_name = method[1:]
-            if is_notification:
-                await agent.ext_notification(ext_name, params or {})
-                return None
-            return await agent.ext_method(ext_name, params or {})
+        case str() if method.startswith("_") and is_notification:
+            await agent.ext_notification(method[1:], params or {})
+            return None
+        case str() if method.startswith("_"):
+            return await agent.ext_method(method[1:], params or {})
         case _:
             raise RequestError.method_not_found(method)
