@@ -11,6 +11,7 @@ from uuid import UUID, uuid4
 from llmling import BasePrompt, PromptMessage, StaticPrompt
 from llmling.config.models import BaseResource
 from psygnal import Signal
+from pydantic_ai import UserPromptPart
 from upathtools import read_path
 
 from llmling_agent.log import get_logger
@@ -210,7 +211,7 @@ class ConversationManager:
             if max_tokens:
                 # Count tokens in this message
                 if msg.cost_info:
-                    msg_tokens = msg.cost_info.token_usage["total"]
+                    msg_tokens = msg.cost_info.token_usage.total_tokens
                 else:
                     # Fallback to tiktoken if no cost info
                     msg_tokens = self.get_message_tokens(msg)
@@ -236,8 +237,10 @@ class ConversationManager:
                 case BasePrompt():
                     await self.add_context_from_prompt(source)
         except Exception:
-            msg = "Failed to load context from %s"
-            logger.exception(msg, "file" if isinstance(source, str) else source.type)
+            logger.exception(
+                "Failed to load context",
+                source="file" if isinstance(source, str) else source.type,
+            )
 
     def load_history_from_database(
         self,
@@ -383,8 +386,13 @@ class ConversationManager:
                     messages = await self._agent.context.storage.filter_messages(history)
                 else:
                     messages = [
-                        ChatMessage(content=await to_prompt(p), role="user")
+                        ChatMessage(
+                            content=prompt,
+                            role="user",
+                            parts=[UserPromptPart(content=prompt)],
+                        )
                         for p in history
+                        if (prompt := await to_prompt(p))
                     ]
 
             if replace_history:
