@@ -119,7 +119,7 @@ class Interactions[TDeps, TResult]:
 
         while True:
             if max_rounds and rounds >= max_rounds:
-                logger.debug("Conversation ended: max rounds (%d) reached", max_rounds)
+                logger.debug("Conversation ended", max_rounds=max_rounds)
                 return
 
             response = await current_node.run(
@@ -414,7 +414,6 @@ List your selections, one per line, followed by your reasoning."""
                 # explanation: str | None = None
 
             result = await self.agent.run(final_prompt, output_type=Extraction)
-
             # Convert model instance to actual type
             return as_type(**result.content.instance.model_dump())  # type: ignore
 
