@@ -2,10 +2,8 @@
 
 from llmling_agent.functional.auto_generate import auto_callable
 from llmling_agent.functional.run import (
-    run_agent_pipeline,
-    run_agent_pipeline_sync,
-    run_with_model,
-    run_with_model_sync,
+    run_agent,
+    run_agent_sync,
 )
 from llmling_agent.functional.structure import (
     get_structured,
@@ -18,8 +16,6 @@ __all__ = [
     "get_structured",
     "get_structured_multiple",
     "pick_one",
-    "run_agent_pipeline",
-    "run_agent_pipeline_sync",
-    "run_with_model",
-    "run_with_model_sync",
+    "run_agent",
+    "run_agent_sync",
 ]
