@@ -13,7 +13,6 @@ from llmling_agent.utils.count_tokens import batch_count_tokens, count_tokens
 
 
 if TYPE_CHECKING:
-    from collections.abc import Sequence
     from datetime import datetime
 
     from bigtree import DAGNode
@@ -48,8 +47,8 @@ class ChatMessageContainer(EventedList[ChatMessage[Any]]):
             Token count for the message
         """
         if message.cost_info:
-            return message.cost_info.token_usage["total"]
-        return count_tokens(str(message.content), message.model_name)
+            return message.cost_info.token_usage.total_tokens
+        return count_tokens(str(message.usage.total_tokens), message.model_name)
 
     def get_history_tokens(self, fallback_model: str | None = None) -> int:
         """Get total token count for all messages.
@@ -61,7 +60,7 @@ class ChatMessageContainer(EventedList[ChatMessage[Any]]):
             Total token count across all messages
         """
         # Use cost_info if available
-        total = sum(msg.cost_info.token_usage["total"] for msg in self if msg.cost_info)
+        total = sum(m.cost_info.token_usage.total_tokens for m in self if m.cost_info)
 
         # For messages without cost_info, estimate using tiktoken
         if msgs := [msg for msg in self if not msg.cost_info]:
@@ -123,48 +122,6 @@ class ChatMessageContainer(EventedList[ChatMessage[Any]]):
             messages = messages[-max_messages:]
         return messages
 
-    def get_context_window(
-        self,
-        *,
-        max_tokens: int | None = None,
-        max_messages: int | None = None,
-        include_system: bool = True,
-    ) -> list[ChatMessage[Any]]:
-        """Get messages respecting token and message limits.
-
-        Args:
-            max_tokens: Optional token limit for window
-            max_messages: Optional message count limit
-            include_system: Whether to include system messages
-
-        Returns:
-            List of messages fitting within constraints
-        """
-        # Filter system messages if needed
-        history: Sequence[ChatMessage[Any]] = self
-        if not include_system:
-            history = [msg for msg in self if msg.role != "system"]
-
-        # Apply message limit if specified
-        if max_messages:
-            history = history[-max_messages:]
-
-        # Apply token limit if specified
-        if max_tokens:
-            token_count = 0
-            filtered: list[Any] = []
-
-            # Work backwards from most recent
-            for msg in reversed(history):
-                msg_tokens = self.get_message_tokens(msg)
-                if token_count + msg_tokens > max_tokens:
-                    break
-                token_count += msg_tokens
-                filtered.insert(0, msg)
-            history = filtered
-
-        return list(history)
-
     def get_between(
         self,
         *,
