@@ -14,7 +14,6 @@ from llmling_agent.messaging.messages import ChatMessage
 from llmling_agent.prompts.convert import convert_prompts
 from llmling_agent.talk.stats import AggregatedTalkStats
 from llmling_agent.tools import ToolCallInfo
-from llmling_agent.utils.inspection import has_return_type
 from llmling_agent.utils.tasks import TaskManager
 
 
@@ -28,11 +27,11 @@ if TYPE_CHECKING:
     from toprompt import AnyPromptType
 
     from llmling_agent.common_types import AnyTransformFn, AsyncFilterFn, QueueStrategy
+    from llmling_agent.mcp_server.client import ContextualProgressHandler
     from llmling_agent.messaging.context import NodeContext
     from llmling_agent.messaging.messagenode import MessageNode
     from llmling_agent.models.content import Content
     from llmling_agent.talk import Talk, TeamTalk
-    from llmling_agent.talk.stats import AggregatedMessageStats, MessageStats
     from llmling_agent_config.forward_targets import ConnectionType
     from llmling_agent_config.mcp_server import MCPServerConfig
     from llmling_agent_config.providers import ProcessorCallback
@@ -60,13 +59,13 @@ class MessageEmitter[TDeps, TResult](ABC):
         context: NodeContext | None = None,
         mcp_servers: Sequence[str | MCPServerConfig] | None = None,
         enable_logging: bool = True,
+        progress_handler: ContextualProgressHandler | None = None,
     ):
         """Initialize message node."""
         super().__init__()
         from llmling_agent.mcp_server.manager import MCPManager
         from llmling_agent.messaging.connection_manager import ConnectionManager
         from llmling_agent.messaging.event_manager import EventManager
-        from llmling_agent.messaging.node_logger import NodeLogger
 
         self.task_manager = TaskManager()
         self._name = name or self.__class__.__name__
@@ -75,11 +74,28 @@ class MessageEmitter[TDeps, TResult](ABC):
         self._events = EventManager(self, enable_events=True)
         servers = mcp_servers or []
         name = f"node_{self._name}"
-        self.mcp = MCPManager(name, servers=servers, context=context, owner=self.name)
-        self._logger = NodeLogger(self, enable_db_logging=enable_logging)
+        self.mcp = MCPManager(
+            name,
+            servers=servers,
+            context=context,
+            owner=self.name,
+            progress_handler=progress_handler,
+        )
+        self.enable_db_logging = enable_logging
+        self.conversation_id = str(uuid4())
+        # Initialize conversation record if enabled
+
+        # Connect to the combined signal to capture all messages
+        # TODO: need to check this
+        # node.message_received.connect(self.log_message)
 
     async def __aenter__(self) -> Self:
         """Initialize base message node."""
+        if self.enable_db_logging:
+            await self.context.storage.log_conversation(
+                conversation_id=self.conversation_id,
+                node_name=self.name,
+            )
         try:
             await self._events.__aenter__()
             await self.mcp.__aenter__()
@@ -101,12 +117,6 @@ class MessageEmitter[TDeps, TResult](ABC):
         await self.mcp.__aexit__(exc_type, exc_val, exc_tb)
         await self.task_manager.cleanup_tasks()
 
-    @property
-    @abstractmethod
-    def stats(self) -> MessageStats | AggregatedMessageStats:
-        """Get stats for this node."""
-        raise NotImplementedError
-
     @property
     def connection_stats(self) -> AggregatedTalkStats:
         """Get stats for all active connections of this node."""
@@ -241,14 +251,11 @@ class MessageEmitter[TDeps, TResult](ABC):
         """Create connection(s) to target(s)."""
         # Handle callable case
         from llmling_agent import MessageNode
-        from llmling_agent.agent import Agent, StructuredAgent
+        from llmling_agent.agent import Agent
         from llmling_agent.delegation.base_team import BaseTeam
 
         if callable(target):
-            if has_return_type(target, str):
-                target = Agent.from_callback(target)
-            else:
-                target = StructuredAgent.from_callback(target)
+            target = Agent.from_callback(target)
             if pool := self.context.pool:
                 pool.register(target.name, target)
         # we are explicit here just to make disctinction clear, we only want sequences
@@ -258,10 +265,7 @@ class MessageEmitter[TDeps, TResult](ABC):
             for t in target:
                 match t:
                     case _ if callable(t):
-                        if has_return_type(t, str):
-                            other: MessageNode = Agent.from_callback(t)
-                        else:
-                            other = StructuredAgent.from_callback(t)
+                        other: MessageNode = Agent.from_callback(t)
                         if pool := self.context.pool:
                             pool.register(other.name, other)
                         targets.append(other)
@@ -365,7 +369,7 @@ class MessageEmitter[TDeps, TResult](ABC):
             store_history: Whether to store in conversation history
             **kwargs: Additional arguments for _run
         """
-        from llmling_agent import Agent, StructuredAgent
+        from llmling_agent import Agent
 
         user_msg, prompts = await self.pre_run(*prompt)
         message = await self._run(
@@ -379,9 +383,10 @@ class MessageEmitter[TDeps, TResult](ABC):
         if len(prompt) == 1 and isinstance(prompt[0], ChatMessage):
             message = message.forwarded(prompt[0])
 
-        if store_history and isinstance(self, Agent | StructuredAgent):
+        if store_history and isinstance(self, Agent):
             self.conversation.add_chat_messages([user_msg, message])
         self.message_sent.emit(message)
+        await self.log_message(message)
         await self.connections.route_message(message, wait=wait_for_connections)
         return message
 
@@ -392,3 +397,18 @@ class MessageEmitter[TDeps, TResult](ABC):
         **kwargs: Any,
     ) -> Coroutine[None, None, ChatMessage[TResult]]:
         """Implementation-specific run logic."""
+
+    async def get_message_history(self, limit: int | None = None) -> list[ChatMessage]:
+        """Get message history from storage."""
+        if not self.enable_db_logging:
+            return []  # No history if not logging
+
+        from llmling_agent_config.session import SessionQuery
+
+        query = SessionQuery(name=self.conversation_id, limit=limit)
+        return await self.context.storage.filter_messages(query)
+
+    async def log_message(self, message: ChatMessage):
+        """Handle message from chat signal."""
+        if self.enable_db_logging:
+            await self.context.storage.log_message(message)  # pyright: ignore
