@@ -9,11 +9,13 @@ from uuid import uuid4
 
 from anyenv import method_spawner
 from psygnal import Signal
+from pydantic_ai import UserPromptPart
 
 from llmling_agent.messaging.messageemitter import MessageEmitter
 from llmling_agent.messaging.messages import ChatMessage
 from llmling_agent.prompts.convert import convert_prompts
 from llmling_agent.tools import ToolCallInfo
+from llmling_agent_providers.pydanticai.convert_content import content_to_pydantic_ai
 
 
 if TYPE_CHECKING:
@@ -54,8 +56,13 @@ class MessageNode[TDeps, TResult](MessageEmitter[TDeps, TResult]):
             # Update received message's chain to show it came through its source
             user_msg = user_msg.forwarded(prompt[0])
             # clear cost info to avoid double-counting
-            user_msg = replace(user_msg, role="user", cost_info=None)
             final_prompt = "\n\n".join(str(p) for p in prompts)
+            user_msg = replace(
+                user_msg,
+                role="user",
+                cost_info=None,
+                parts=[UserPromptPart(content=[final_prompt])],
+            )
         else:
             prompts = await convert_prompts(prompt)
             final_prompt = "\n\n".join(str(p) for p in prompts)
@@ -64,6 +71,9 @@ class MessageNode[TDeps, TResult](MessageEmitter[TDeps, TResult]):
                 content=final_prompt,
                 role="user",
                 conversation_id=str(uuid4()),
+                parts=[
+                    UserPromptPart(content=[content_to_pydantic_ai(i) for i in prompts])
+                ],
             )
         self.message_received.emit(user_msg)
         self.context.current_prompt = final_prompt
