@@ -3,14 +3,15 @@
 from __future__ import annotations
 
 import dataclasses
-from dataclasses import asdict, dataclass, field, replace
+from dataclasses import dataclass, field, replace
 from decimal import Decimal
-from typing import TYPE_CHECKING, Any, Literal, Self, TypedDict, TypeVar
+from typing import TYPE_CHECKING, Any, Literal, Self, TypeVar
+import uuid
 from uuid import uuid4
 
 from genai_prices import calc_price
 from pydantic import BaseModel
-from pydantic_ai import RequestUsage
+from pydantic_ai import ModelRequest, ModelResponse, RequestUsage
 import tokonomics
 
 from llmling_agent.common_types import MessageRole, SimpleJsonType  # noqa: TC001
@@ -22,7 +23,12 @@ if TYPE_CHECKING:
     from collections.abc import Sequence
     from datetime import datetime
 
-    from pydantic_ai import FinishReason, ModelResponsePart, RunUsage
+    from pydantic_ai import (
+        FinishReason,
+        ModelRequestPart,
+        ModelResponsePart,
+        RunUsage,
+    )
 
     from llmling_agent.tools import ToolCallInfo
 
@@ -39,7 +45,7 @@ Time: {{ timestamp.strftime('%Y-%m-%d %H:%M:%S') }}
 {{ content }}
 ----------------------------------------
 {%- if show_costs and cost_info %}
-Tokens: {{ "{:,}".format(cost_info.token_usage['total']) }}
+Tokens: {{ "{:,}".format(cost_info.token_usage.total_tokens) }}
 Cost: ${{ "%.5f"|format(cost_info.total_cost) }}
 {%- if response_time %}
 Response time: {{ "%.2f"|format(response_time) }}s
@@ -63,7 +69,7 @@ MARKDOWN_TEMPLATE = """## {{ name or role.title() }}
 {%- if show_costs and cost_info %}
 ---
 **Stats:**
-- Tokens: {{ "{:,}".format(cost_info.token_usage['total']) }}
+- Tokens: {{ "{:,}".format(cost_info.token_usage.total_tokens) }}
 - Cost: ${{ "%.4f"|format(cost_info.total_cost) }}
 {%- if response_time %}
 - Response time: {{ "%.2f"|format(response_time) }}s
@@ -89,22 +95,11 @@ MESSAGE_TEMPLATES = {
 }
 
 
-class TokenUsage(TypedDict):
-    """Token usage statistics from model responses."""
-
-    total: int
-    """Total tokens used"""
-    prompt: int
-    """Tokens used in the prompt"""
-    completion: int
-    """Tokens used in the completion"""
-
-
 @dataclass(frozen=True)
 class TokenCost:
     """Combined token and cost tracking."""
 
-    token_usage: TokenUsage
+    token_usage: RunUsage
     """Token counts for prompt and completion"""
     total_cost: Decimal
     """Total cost in USD"""
@@ -126,13 +121,7 @@ class TokenCost:
         ):
             logger.debug("Missing token counts in Usage object")
             return None
-
-        token_usage = TokenUsage(
-            total=usage.total_tokens,
-            prompt=usage.input_tokens,
-            completion=usage.output_tokens,
-        )
-        logger.debug("Token usage: %s", token_usage)
+        logger.debug("Token usage", usage=usage)
 
         # return cls(token_usage=token_usage, total_cost=Decimal(total_cost))
         if model in {"None", "test"}:
@@ -154,7 +143,7 @@ class TokenCost:
                 )
                 price = Decimal(cost.total_cost if cost else 0)
 
-        return cls(token_usage=token_usage, total_cost=price)
+        return cls(token_usage=usage, total_cost=price)
 
 
 @dataclass
@@ -169,7 +158,7 @@ class ChatMessage[TContent]:
     """Message content, typed as TContent (either str or BaseModel)."""
 
     role: MessageRole
-    """Role of the message sender (user/assistant/system)."""
+    """Role of the message sender (user/assistant)."""
 
     metadata: SimpleJsonType = field(default_factory=dict)
     """Additional metadata about the message."""
@@ -204,7 +193,7 @@ class ChatMessage[TContent]:
     provider_details: dict[str, Any] = field(default_factory=dict)
     """Provider specific metadata / extra information."""
 
-    parts: Sequence[ModelResponsePart] = field(default_factory=list)
+    parts: Sequence[ModelResponsePart | ModelRequestPart] = field(default_factory=list)
     """The parts of the model message."""
 
     usage: RequestUsage = field(default_factory=RequestUsage)
@@ -217,9 +206,6 @@ class ChatMessage[TContent]:
     model_name: str | None = None
     """The name of the model that generated the response."""
 
-    kind: Literal["response"] = "response"
-    """Message type identifier, this is available on all parts as a discriminator."""
-
     provider_name: str | None = None
     """The name of the LLM provider that generated the response."""
 
@@ -233,6 +219,84 @@ class ChatMessage[TContent]:
 
     Normalized to OpenTelemetry values."""
 
+    @property
+    def kind(self) -> Literal["request", "response"]:
+        """Role of the message."""
+        match self.role:
+            case "assistant":
+                return "response"
+            case "user":
+                return "request"
+
+    def to_pydantic_ai(self) -> ModelRequest | ModelResponse:
+        """Convert this message to a Pydantic model."""
+        match self.kind:
+            case "request":
+                return ModelRequest(parts=self.parts, instructions=None)  # type: ignore
+            case "response":
+                return ModelResponse(
+                    parts=self.parts,  # type: ignore
+                    usage=self.usage,
+                    model_name=self.model_name,
+                    timestamp=self.timestamp,
+                    provider_name=self.provider_name,
+                    provider_details=self.provider_details,
+                    finish_reason=self.finish_reason,
+                    provider_response_id=self.provider_response_id,
+                )
+
+    @classmethod
+    def from_pydantic_ai[TContentType](
+        cls,
+        content: TContentType,
+        message: ModelRequest | ModelResponse,
+        conversation_id: str | None = None,
+        name: str | None = None,
+        message_id: str | None = None,
+        forwarded_from: list[str] | None = None,
+    ) -> ChatMessage[TContentType]:
+        """Convert a Pydantic model to a ChatMessage."""
+        match message:
+            case ModelRequest(parts=parts, instructions=_instructions):
+                return ChatMessage(
+                    parts=parts,
+                    content=content,
+                    role="user" if message.kind == "request" else "assistant",
+                    message_id=message_id or str(uuid.uuid4()),
+                    # instructions=instructions,
+                    forwarded_from=forwarded_from or [],
+                    name=name,
+                )
+            case ModelResponse(
+                parts=parts,
+                usage=usage,
+                model_name=model_name,
+                timestamp=timestamp,
+                provider_name=provider_name,
+                provider_details=provider_details,
+                finish_reason=finish_reason,
+                provider_response_id=provider_response_id,
+            ):
+                return ChatMessage(
+                    role="user" if message.kind == "request" else "assistant",
+                    content=content,
+                    parts=parts,
+                    usage=usage,
+                    message_id=message_id or str(uuid.uuid4()),
+                    conversation_id=conversation_id,
+                    model_name=model_name,
+                    timestamp=timestamp,
+                    provider_name=provider_name,
+                    provider_details=provider_details or {},
+                    finish_reason=finish_reason,
+                    provider_response_id=provider_response_id,
+                    name=name,
+                    forwarded_from=forwarded_from or [],
+                )
+            case _:
+                msg = f"Unknown message kind: {message.kind}"
+                raise ValueError(msg)
+
     def forwarded(self, previous_message: ChatMessage[Any]) -> Self:
         """Create new message showing it was forwarded from another message.
 
@@ -293,9 +357,13 @@ class ChatMessage[TContent]:
             case _:
                 msg = f"Invalid style: {style}"
                 raise ValueError(msg)
-
         template_obj = env.from_string(template_str)
-        vars_ = {**asdict(self), "show_metadata": show_metadata, "show_costs": show_costs}
+        vars_ = {
+            **(self.__dict__),
+            "show_metadata": show_metadata,
+            "show_costs": show_costs,
+        }
+        print(vars_)
         if variables:
             vars_.update(variables)
 
