@@ -24,7 +24,6 @@ from upath import UPath
 
 from llmling_agent import log
 from llmling_agent.common_types import EndStrategy  # noqa: TC001
-from llmling_agent.config import Capabilities
 from llmling_agent.resource_providers.static import StaticResourceProvider
 from llmling_agent_config.environment import (
     AgentEnvironment,  # noqa: TC001
@@ -34,8 +33,8 @@ from llmling_agent_config.environment import (
 from llmling_agent_config.knowledge import Knowledge  # noqa: TC001
 from llmling_agent_config.models import AnyModelConfig  # noqa: TC001
 from llmling_agent_config.nodes import NodeConfig
+from llmling_agent_config.output_types import StructuredResponseConfig  # noqa: TC001
 from llmling_agent_config.providers import ProviderConfig  # noqa: TC001
-from llmling_agent_config.result_types import StructuredResponseConfig  # noqa: TC001
 from llmling_agent_config.session import MemoryConfig, SessionQuery
 from llmling_agent_config.system_prompts import PromptConfig  # noqa: TC001
 from llmling_agent_config.tools import BaseToolConfig, ToolConfig  # noqa: TC001
@@ -59,12 +58,11 @@ class AgentConfig(NodeConfig):
     """Configuration for a single agent in the system.
 
     Defines an agent's complete configuration including its model, environment,
-    capabilities, and behavior settings. Each agent can have its own:
+    and behavior settings. Each agent can have its own:
     - Language model configuration
     - Environment setup (tools and resources)
     - Response type definitions
     - System prompts and default user prompts
-    - Role-based capabilities
 
     The configuration can be loaded from YAML or created programmatically.
     """
@@ -88,13 +86,10 @@ class AgentConfig(NodeConfig):
     environment: str | AgentEnvironment | None = None
     """Environments configuration (path or object)"""
 
-    capabilities: Capabilities = Field(default_factory=Capabilities)
-    """Current agent's capabilities."""
-
     session: str | SessionQuery | MemoryConfig | None = None
     """Session configuration for conversation recovery."""
 
-    result_type: str | StructuredResponseConfig | None = None
+    output_type: str | StructuredResponseConfig | None = None
     """Name of the response definition to use"""
 
     retries: int = 1
@@ -145,23 +140,23 @@ class AgentConfig(NodeConfig):
 
     def is_structured(self) -> bool:
         """Check if this config defines a structured agent."""
-        return self.result_type is not None
+        return self.output_type is not None
 
     @model_validator(mode="before")
     @classmethod
-    def validate_result_type(cls, data: dict[str, Any]) -> dict[str, Any]:
+    def validate_output_type(cls, data: dict[str, Any]) -> dict[str, Any]:
         """Convert result type and apply its settings."""
-        result_type = data.get("result_type")
-        if isinstance(result_type, dict):
+        output_type = data.get("output_type")
+        if isinstance(output_type, dict):
             # Extract response-specific settings
-            tool_name = result_type.pop("result_tool_name", None)
-            tool_description = result_type.pop("result_tool_description", None)
-            retries = result_type.pop("output_retries", None)
+            tool_name = output_type.pop("result_tool_name", None)
+            tool_description = output_type.pop("result_tool_description", None)
+            retries = output_type.pop("output_retries", None)
 
             # Convert remaining dict to ResponseDefinition
-            if "type" not in result_type["response_schema"]:
-                result_type["response_schema"]["type"] = "inline"
-            data["result_type"]["response_schema"] = InlineSchemaDef(**result_type)
+            if "type" not in output_type["response_schema"]:
+                output_type["response_schema"]["type"] = "inline"
+            data["output_type"]["response_schema"] = InlineSchemaDef(**output_type)
 
             # Apply extracted settings to agent config
             if tool_name:
@@ -181,7 +176,7 @@ class AgentConfig(NodeConfig):
             data["model"] = {"type": "string", "identifier": model}
         return data
 
-    async def get_toolsets(self) -> list[ResourceProvider]:
+    def get_toolsets(self) -> list[ResourceProvider]:
         """Get all resource providers for this agent."""
         providers: list[ResourceProvider] = []
 
@@ -191,10 +186,8 @@ class AgentConfig(NodeConfig):
                 provider = toolset_config.get_provider()
                 providers.append(provider)
             except Exception as e:
-                logger.exception(
-                    "Failed to create provider for toolset: %r", toolset_config
-                )
-                msg = f"Failed to create provider for toolset: {e}"
+                msg = "Failed to create provider for toolset"
+                logger.exception(msg, toolset_config)
                 raise ValueError(msg) from e
 
         return providers
@@ -279,7 +272,7 @@ class AgentConfig(NodeConfig):
                         base_path = Path(self.config_file_path).parent
                         template_path = base_path / path
 
-                    template_content = template_path.read_text()
+                    template_content = template_path.read_text("utf-8")
                     # Create a template-based prompt
                     # (for now as StaticPrompt with placeholder)
                     static_prompt = StaticPrompt(
@@ -368,7 +361,7 @@ class AgentConfig(NodeConfig):
                         base_path = Path(self.config_file_path).parent
                         template_path = base_path / path
 
-                    template_content = template_path.read_text()
+                    template_content = template_path.read_text("utf-8")
                     template_ctx = {"agent": context, **variables}
                     rendered_prompts.append(render_prompt(template_content, template_ctx))
                 case LibraryPromptConfig(reference=reference):
