@@ -3,6 +3,7 @@
 from __future__ import annotations
 
 from functools import cached_property
+from pathlib import Path
 from typing import TYPE_CHECKING, Any, Self
 
 from pydantic import ConfigDict, Field, model_validator
@@ -15,21 +16,19 @@ from llmling_agent_config.converters import ConversionConfig
 from llmling_agent_config.mcp_server import (
     BaseMCPServerConfig,
     MCPServerConfig,  # noqa: TC001
-    StdioMCPServerConfig,
 )
 from llmling_agent_config.observability import ObservabilityConfig
+from llmling_agent_config.output_types import StructuredResponseConfig  # noqa: TC001
 from llmling_agent_config.pool_server import MCPPoolServerConfig
 from llmling_agent_config.providers import BaseProviderConfig
 from llmling_agent_config.resources import (  # noqa: TC001
     ResourceConfig,
     SourceResourceConfig,
 )
-from llmling_agent_config.result_types import StructuredResponseConfig  # noqa: TC001
 from llmling_agent_config.storage import StorageConfig
 from llmling_agent_config.system_prompts import PromptLibraryConfig
 from llmling_agent_config.task import Job  # noqa: TC001
 from llmling_agent_config.teams import TeamConfig  # noqa: TC001
-from llmling_agent_config.ui import StdlibUIConfig, UIConfig  # noqa: TC001
 from llmling_agent_config.workers import (
     AgentWorkerConfig,
     BaseWorkerConfig,
@@ -38,8 +37,9 @@ from llmling_agent_config.workers import (
 
 
 if TYPE_CHECKING:
-    from llmling_agent import AgentPool, AnyAgent
-    from llmling_agent.common_types import StrPath
+    from upath.types import JoinablePathLike
+
+    from llmling_agent import Agent, AgentPool
     from llmling_agent.prompts.manager import PromptManager
 
 
@@ -74,9 +74,6 @@ class AgentsManifest(Schema):
             cached: true
     """
 
-    ui: UIConfig = Field(default_factory=StdlibUIConfig)
-    """UI configuration."""
-
     agents: dict[str, AgentConfig] = Field(default_factory=dict)
     """Mapping of agent IDs to their configurations"""
 
@@ -132,15 +129,13 @@ class AgentsManifest(Schema):
 
                 for worker in workers:
                     match worker:
-                        case str() as name:
+                        case str() as name if name in teams:
                             # Determine type based on presence in teams/agents
-                            if name in teams:
-                                normalized.append(TeamWorkerConfig(name=name))
-                            elif name in agents:
-                                normalized.append(AgentWorkerConfig(name=name))
-                            else:
-                                # Default to agent if type can't be determined
-                                normalized.append(AgentWorkerConfig(name=name))
+                            normalized.append(TeamWorkerConfig(name=name))
+                        case str() as name if name in agents:
+                            normalized.append(AgentWorkerConfig(name=name))
+                        case str():  # Default to agent if type can't be determined
+                            normalized.append(AgentWorkerConfig(name=name))
 
                         case dict() as config:
                             # If type is explicitly specified, use it
@@ -307,8 +302,10 @@ class AgentsManifest(Schema):
     def get_mcp_servers(self) -> list[MCPServerConfig]:
         """Get processed MCP server configurations.
 
-        Converts string entries to StdioMCPServerConfig configs by splitting
-        into command and arguments.
+        Converts string entries to appropriate MCP server configs based on heuristics:
+        - URLs ending with "/sse" -> SSE server
+        - URLs starting with http(s):// -> HTTP server
+        - Everything else -> stdio command
 
         Returns:
             List of MCPServerConfig instances
@@ -316,21 +313,10 @@ class AgentsManifest(Schema):
         Raises:
             ValueError: If string entry is empty
         """
-        configs: list[MCPServerConfig] = []
-
-        for server in self.mcp_servers:
-            match server:
-                case str():
-                    parts = server.split()
-                    if not parts:
-                        msg = "Empty MCP server command"
-                        raise ValueError(msg)
-
-                    configs.append(StdioMCPServerConfig(command=parts[0], args=parts[1:]))
-                case BaseMCPServerConfig():
-                    configs.append(server)
-
-        return configs
+        return [
+            BaseMCPServerConfig.from_string(cfg) if isinstance(cfg, str) else cfg
+            for cfg in self.mcp_servers
+        ]
 
     @cached_property
     def prompt_manager(self) -> PromptManager:
@@ -341,34 +327,31 @@ class AgentsManifest(Schema):
 
     # @model_validator(mode="after")
     # def validate_response_types(self) -> AgentsManifest:
-    #     """Ensure all agent result_types exist in responses or are inline."""
+    #     """Ensure all agent output_types exist in responses or are inline."""
     #     for agent_id, agent in self.agents.items():
     #         if (
-    #             isinstance(agent.result_type, str)
-    #             and agent.result_type not in self.responses
+    #             isinstance(agent.output_type, str)
+    #             and agent.output_type not in self.responses
     #         ):
-    #             msg = f"'{agent.result_type=}' for '{agent_id=}' not found in responses"
+    #             msg = f"'{agent.output_type=}' for '{agent_id=}' not found in responses"
     #             raise ValueError(msg)
     #     return self
 
     def get_agent[TAgentDeps](
         self, name: str, deps: TAgentDeps | None = None
-    ) -> AnyAgent[TAgentDeps, Any]:
+    ) -> Agent[TAgentDeps, Any]:
         # TODO: Make this method async to support async function prompts
         from llmling import RuntimeConfig
 
         from llmling_agent import Agent, AgentContext
 
         config = self.agents[name]
-        # Create runtime without async context
         cfg = config.get_config()
-        runtime = RuntimeConfig.from_config(cfg)
-
+        runtime = RuntimeConfig.from_config(cfg)  # Create runtime without async context
         # Create context with config path and capabilities
         context = AgentContext[TAgentDeps](
             node_name=name,
             data=deps,
-            capabilities=config.capabilities,
             definition=self,
             config=config,
             runtime=runtime,
@@ -377,8 +360,6 @@ class AgentsManifest(Schema):
         )
 
         # Resolve system prompts with new PromptConfig types
-        from pathlib import Path
-
         from llmling_agent_config.system_prompts import (
             FilePromptConfig,
             FunctionPromptConfig,
@@ -396,7 +377,7 @@ class AgentsManifest(Schema):
                     if not template_path.is_absolute() and config.config_file_path:
                         template_path = Path(config.config_file_path).parent / path
 
-                    template_content = template_path.read_text()
+                    template_content = template_path.read_text("utf-8")
                     if variables:  # Apply variables if any
                         from jinja2 import Template
 
@@ -407,7 +388,7 @@ class AgentsManifest(Schema):
                     sys_prompts.append(content)
                 case LibraryPromptConfig(reference=reference):
                     try:  # Load from library
-                        content = self.prompt_manager.get_sync(reference)
+                        content = self.prompt_manager.get.sync(reference)
                         sys_prompts.append(content)
                     except Exception as e:
                         msg = (
@@ -420,7 +401,7 @@ class AgentsManifest(Schema):
                     content = function(**arguments)  # Call function to get prompt content
                     sys_prompts.append(content)
         # Create agent with runtime and context
-        agent = Agent[Any](
+        return Agent(
             runtime=runtime,
             context=context,
             provider=config.get_provider(),
@@ -431,13 +412,10 @@ class AgentsManifest(Schema):
             session=config.get_session_config(),
             output_retries=config.output_retries,
             end_strategy=config.end_strategy,
-            capabilities=config.capabilities,
             debug=config.debug,
+            output_type=self.get_output_type(name) or str,
             # name=config.name or name,
         )
-        if result_type := self.get_result_type(name):
-            return agent.to_structured(result_type)
-        return agent
 
     def get_used_providers(self) -> set[str]:
         """Get all providers configured in this manifest."""
@@ -450,7 +428,7 @@ class AgentsManifest(Schema):
         return providers
 
     @classmethod
-    def from_file(cls, path: StrPath) -> Self:
+    def from_file(cls, path: JoinablePathLike) -> Self:
         """Load agent configuration from YAML file.
 
         Args:
@@ -488,19 +466,19 @@ class AgentsManifest(Schema):
 
         return AgentPool(manifest=self)
 
-    def get_result_type(self, agent_name: str) -> type[Any] | None:
+    def get_output_type(self, agent_name: str) -> type[Any] | None:
         """Get the resolved result type for an agent.
 
         Returns None if no result type is configured.
         """
         agent_config = self.agents[agent_name]
-        if not agent_config.result_type:
+        if not agent_config.output_type:
             return None
-        logger.debug("Building response model for %r", agent_config.result_type)
-        if isinstance(agent_config.result_type, str):
-            response_def = self.responses[agent_config.result_type]
+        logger.debug("Building response model for %r", agent_config.output_type)
+        if isinstance(agent_config.output_type, str):
+            response_def = self.responses[agent_config.output_type]
             return response_def.response_schema.get_schema()  # type: ignore
-        return agent_config.result_type.response_schema.get_schema()  # type: ignore
+        return agent_config.output_type.response_schema.get_schema()  # type: ignore
 
 
 if __name__ == "__main__":
