@@ -5,12 +5,13 @@ from __future__ import annotations
 from typing import TYPE_CHECKING, Any
 
 from llmling_agent.prompts.base import BasePromptProvider
+from llmling_agent_config.system_prompts import StaticPromptConfig
 
 
 if TYPE_CHECKING:
     from llmling.config.runtime import RuntimeConfig
 
-    from llmling_agent_config.prompts import SystemPrompt
+    from llmling_agent_config.system_prompts import StaticPromptConfig
 
 
 class BuiltinPromptProvider(BasePromptProvider):
@@ -19,7 +20,7 @@ class BuiltinPromptProvider(BasePromptProvider):
     supports_variables = True
     name = "builtin"
 
-    def __init__(self, manifest_prompts: dict[str, SystemPrompt]):
+    def __init__(self, manifest_prompts: dict[str, StaticPromptConfig]):
         from jinjarope import Environment
 
         self.prompts = manifest_prompts
@@ -44,14 +45,10 @@ class BuiltinPromptProvider(BasePromptProvider):
         # Parse template to find required variables
         ast = self.env.parse(content)
         required_vars = meta.find_undeclared_variables(ast)
-
-        if variables:
-            # Check for unknown variables
-            unknown_vars = set(variables) - required_vars
-            if unknown_vars:
-                vars_ = ", ".join(unknown_vars)
-                msg = f"Unknown variables for prompt {identifier}: {vars_}"
-                raise KeyError(msg)
+        if variables and (unknown_vars := (set(variables) - required_vars)):
+            vars_ = ", ".join(unknown_vars)
+            msg = f"Unknown variables for prompt {identifier}: {vars_}"
+            raise KeyError(msg)
 
         if required_vars:
             if not variables:
