@@ -24,7 +24,7 @@ if TYPE_CHECKING:
     from datetime import datetime
     from types import TracebackType
 
-    from pydantic_ai import ModelResponsePart
+    from pydantic_ai import ModelRequestPart, ModelResponsePart
 
     from llmling_agent.common_types import JsonValue
     from llmling_agent.messaging.messages import ChatMessage
@@ -60,11 +60,11 @@ def deserialize_parts(parts_json: str | None) -> Sequence[ModelResponsePart]:
         # Deserialize using pydantic's JSON deserialization
         return parts_adapter.validate_json(parts_json.encode())
     except Exception as e:  # noqa: BLE001
-        logger.warning("Failed to deserialize message parts: %s", e)
+        logger.warning("Failed to deserialize message parts", error=e)
         return []  # Return empty list on failure
 
 
-def serialize_parts(parts: Sequence[ModelResponsePart]) -> str | None:
+def serialize_parts(parts: Sequence[ModelResponsePart | ModelRequestPart]) -> str | None:
     """Serialize pydantic-ai message parts from ChatMessage.
 
     Args:
@@ -92,7 +92,7 @@ def serialize_parts(parts: Sequence[ModelResponsePart]) -> str | None:
         # Serialize using pydantic's JSON serialization
         return parts_adapter.dump_json(serializable_parts).decode()
     except Exception as e:  # noqa: BLE001
-        logger.warning("Failed to serialize message parts: %s", e)
+        logger.warning("Failed to serialize message parts", error=e)
         return str(parts)  # Fallback to string representation
 
 
@@ -242,8 +242,8 @@ class StorageManager:
         if self.config.default_provider:
             if provider := find_provider(self.config.default_provider):
                 return provider
-            msg = "Default provider %s not found or not capable of loading history"
-            logger.warning(msg, self.config.default_provider)
+            msg = "Default provider not found or not capable of loading history"
+            logger.warning(msg, provider=self.config.default_provider)
 
         # Find first capable provider
         for provider in self.providers:
