@@ -77,18 +77,18 @@ class ConnectionRegistry(BaseRegistry[str, Talk]):
     def _on_talk_added(self, name: str, talk: Talk):
         """Handle new talk being added to registry."""
         talk.connection_processed.connect(self._handle_message_flow)
-        logger.debug("Connected signal for talk: %s", name)
+        logger.debug("Connected signal for talk", name=name)
 
     def _on_talk_removed(self, name: str, talk: Talk):
         """Handle talk being removed from registry."""
         talk.connection_processed.disconnect(self._handle_message_flow)
-        logger.debug("Disconnected signal for talk: %s", name)
+        logger.debug("Disconnected signal for talk", name=name)
 
     def _on_talk_changed(self, name: str, old_talk: Talk, new_talk: Talk):
         """Handle talk being replaced in registry."""
         old_talk.connection_processed.disconnect(self._handle_message_flow)
         new_talk.connection_processed.connect(self._handle_message_flow)
-        logger.debug("Reconnected signal for talk: %s", name)
+        logger.debug("Reconnected signal for talk", name=name)
 
     def _handle_message_flow(self, event: Talk.ConnectionProcessed):
         """Forward message flow to global stream."""
