@@ -4,6 +4,6 @@ from __future__ import annotations
 
 from llmling_agent.tools.base import ToolContext, Tool
 from llmling_agent.tools.manager import ToolManager, ToolError
+from llmling_agent.tools.tool_call_info import ToolCallInfo
 
-
-__all__ = ["Tool", "ToolContext", "ToolError", "ToolManager"]
+__all__ = ["Tool", "ToolCallInfo", "ToolContext", "ToolError", "ToolManager"]
