@@ -4,13 +4,13 @@ from __future__ import annotations
 
 from dataclasses import dataclass, field
 import inspect
-from typing import TYPE_CHECKING, Any, Self
+from typing import TYPE_CHECKING, Any, Literal, Self
 
 from llmling import LLMCallableTool
+import logfire
 import schemez  # noqa: TC002
 
 from llmling_agent.log import get_logger
-from llmling_agent.observability import track_tool
 from llmling_agent.utils.inspection import execute
 
 
@@ -25,6 +25,18 @@ if TYPE_CHECKING:
 
 
 logger = get_logger(__name__)
+ToolKind = Literal[
+    "read",
+    "edit",
+    "delete",
+    "move",
+    "search",
+    "execute",
+    "think",
+    "fetch",
+    "switch_mode",
+    "other",
+]
 
 
 @dataclass(frozen=True)
@@ -93,6 +105,9 @@ class Tool:
     cache_enabled: bool = False
     """Whether to enable caching for this tool."""
 
+    category: ToolKind | None = None
+    """The category of the tool."""
+
     @property
     def schema(self) -> schemez.OpenAIFunctionTool:
         """Get the OpenAI function schema for the tool."""
@@ -148,10 +163,10 @@ class Tool:
             lines.extend(f"{indent}    {k}: {v}" for k, v in self.metadata.items())
         return "\n".join(lines)
 
+    @logfire.instrument("Executing tool {self.name} with args={args}, kwargs={kwargs}")
     async def execute(self, *args: Any, **kwargs: Any) -> Any:
         """Execute tool, handling both sync and async cases."""
-        fn = track_tool(self.name)(self.callable.callable)
-        return await execute(fn, *args, **kwargs, use_thread=True)
+        return await execute(self.callable.callable, *args, **kwargs, use_thread=True)
 
     @classmethod
     def from_code(
