@@ -5,38 +5,24 @@ from __future__ import annotations
 import re
 from typing import TYPE_CHECKING, Any
 
-from acp.schema import AvailableCommand, AvailableCommandInput, CommandInputHint
+from acp.schema import AvailableCommand
 from llmling_agent.log import get_logger
+from llmling_agent_acp.commands.acp_commands import ACPCommandContext
 from llmling_agent_acp.commands.mcp_commands import MCPPromptCommand
 
 
-if TYPE_CHECKING:
-    from slashed import CommandStore
-
-
 if TYPE_CHECKING:
     from collections.abc import Callable
 
     from mcp.types import Prompt as MCPPrompt
-    from slashed import BaseCommand, CommandContext, CommandStore
+    from slashed import CommandContext, CommandStore
 
     from llmling_agent.agent.context import AgentContext
     from llmling_agent_acp.session import ACPSession
 
 logger = get_logger(__name__)
 SLASH_PATTERN = re.compile(r"^/([\w-]+)(?:\s+(.*))?$")
-
-
-class ACPOutputWriter:
-    """OutputWriter that immediately sends updates to ACP session."""
-
-    def __init__(self, session: ACPSession) -> None:
-        """Initialize with ACP session for immediate updates."""
-        self.session = session
-
-    async def print(self, message: str = "", **kwargs: Any) -> None:
-        """Send message immediately as session updates."""
-        await self.session.notifications.send_agent_text(message)
+ACP_COMMANDS = {"list-sessions", "load-session", "save-session", "delete-session"}
 
 
 class ACPCommandBridge:
@@ -52,7 +38,7 @@ class ACPCommandBridge:
         self._update_callbacks: list[Callable[[], None]] = []
         self._mcp_prompt_commands: dict[str, MCPPromptCommand] = {}
 
-    def to_available_commands(self, context: AgentContext[Any]) -> list[AvailableCommand]:
+    def get_acp_commands(self, context: AgentContext[Any]) -> list[AvailableCommand]:
         """Convert slashed commands to ACP format.
 
         Args:
@@ -61,7 +47,14 @@ class ACPCommandBridge:
         Returns:
             List of ACP AvailableCommand objects
         """
-        commands = [_convert_command(cmd) for cmd in self.command_store.list_commands()]
+        commands = [
+            AvailableCommand.create(
+                name=cmd.name,
+                description=cmd.description,
+                input_hint=cmd.usage,
+            )
+            for cmd in self.command_store.list_commands()
+        ]
         commands.extend([
             cmd.to_available_command() for cmd in self._mcp_prompt_commands.values()
         ])
@@ -79,33 +72,26 @@ class ACPCommandBridge:
             args = match.group(2) or ""
             command_name, args = command_name, args.strip()
         else:
-            logger.warning("Invalid slash command: %s", command_text)
+            logger.warning("Invalid slash command", command=command_text)
             return
 
         # Check if it's an MCP prompt command first
         if command_name in self._mcp_prompt_commands:
             mcp_cmd = self._mcp_prompt_commands[command_name]
             await mcp_cmd.execute(args, session)
-        # Create output writer that sends directly to session
-        output_writer = ACPOutputWriter(session)
-
-        # Check if it's an ACP-specific command
-        acp_commands = {"list-sessions", "load-session", "save-session", "delete-session"}
-
-        if command_name in acp_commands:
+        if command_name in ACP_COMMANDS:
             # Use ACP context for ACP commands
-            from llmling_agent_acp.acp_commands import ACPCommandContext
 
             acp_ctx = ACPCommandContext(session)
             cmd_ctx: CommandContext = self.command_store.create_context(
                 data=acp_ctx,
-                output_writer=output_writer,
+                output_writer=session.notifications.send_agent_text,
             )
         else:
             # Use regular agent context for other commands
             cmd_ctx = self.command_store.create_context(
                 data=session.agent.context,
-                output_writer=output_writer,
+                output_writer=session.notifications.send_agent_text,
             )
 
         command_str = f"{command_name} {args}".strip()
@@ -139,21 +125,3 @@ class ACPCommandBridge:
                 callback()
             except Exception:
                 logger.exception("Command update callback failed")
-
-
-def _convert_command(command: BaseCommand) -> AvailableCommand:
-    """Convert a single slashed command to ACP format.
-
-    Args:
-        command: Slashed command to convert
-
-    Returns:
-        ACP AvailableCommand
-    """
-    description = command.description
-    spec = (
-        AvailableCommandInput(root=CommandInputHint(hint=command.usage))
-        if command.usage
-        else None
-    )
-    return AvailableCommand(name=command.name, description=description, input=spec)
