@@ -9,40 +9,10 @@ import pytest
 from slashed import CommandStore
 
 from llmling_agent import Agent, AgentPool
-from llmling_agent_acp.command_bridge import ACPCommandBridge, ACPOutputWriter
+from llmling_agent_acp.command_bridge import ACPCommandBridge
 from llmling_agent_acp.session import ACPSession
 
 
-@pytest.mark.asyncio
-async def test_acp_output_writer():
-    """Test that ACPOutputWriter sends updates immediately to session."""
-    # Mock session with notifications
-    mock_session = AsyncMock(spec=ACPSession)
-    mock_session.session_id = "test_session"
-    mock_session.notifications = AsyncMock()
-
-    received_messages = []
-
-    async def capture_message(message):
-        received_messages.append(message)
-
-    mock_session.notifications.send_agent_text.side_effect = capture_message
-
-    writer = ACPOutputWriter(mock_session)
-
-    # Test sending multiple messages
-    await writer.print("First message")
-    await writer.print("Second message")
-
-    # Verify messages were sent immediately
-    expected_message_count = 2
-    assert len(received_messages) == expected_message_count
-
-    # Verify content was sent correctly
-    assert received_messages[0] == "First message"
-    assert received_messages[1] == "Second message"
-
-
 @pytest.mark.asyncio
 async def test_command_bridge_immediate_execution():
     """Test that command execution sends updates immediately."""
@@ -52,7 +22,7 @@ async def test_command_bridge_immediate_execution():
 
     # Set up agent and session
     agent = Agent(name="test_agent", provider=simple_callback)
-    agent_pool = AgentPool[None]()
+    agent_pool = AgentPool()
     agent_pool.register("test_agent", agent)
 
     # Create command store and bridge
@@ -87,11 +57,11 @@ async def test_immediate_send_with_slow_command():
 
     # Create a command that outputs multiple lines with delays
     async def slow_command_func(ctx, args, kwargs):
-        await ctx.output.print("Starting task...")
+        await ctx.print("Starting task...")
         await asyncio.sleep(0.01)  # Small delay
-        await ctx.output.print("Processing...")
+        await ctx.print("Processing...")
         await asyncio.sleep(0.01)  # Small delay
-        await ctx.output.print("Completed!")
+        await ctx.print("Completed!")
 
     # Set up command store
     command_store = CommandStore()
@@ -142,7 +112,7 @@ async def test_immediate_send_error_handling():
     """Test that errors in commands are properly sent immediately."""
 
     async def failing_command(ctx, args, kwargs):
-        await ctx.output.print("Starting...")
+        await ctx.print("Starting...")
         msg = "Command failed!"
         raise ValueError(msg)
 
