@@ -1,14 +1,20 @@
 """Storage configuration."""
 
+from __future__ import annotations
+
 import os
 from pathlib import Path
-from typing import Annotated, Final, Literal
+from typing import TYPE_CHECKING, Annotated, Final, Literal
 
 from platformdirs import user_data_dir
 from pydantic import ConfigDict, Field, SecretStr
 from schemez import Schema
 
 
+if TYPE_CHECKING:
+    from sqlalchemy.ext.asyncio import AsyncEngine
+
+
 LogFormat = Literal["chronological", "conversations"]
 FilterMode = Literal["and", "override"]
 SupportedFormats = Literal["yaml", "toml", "json", "ini"]
@@ -42,9 +48,6 @@ class BaseStorageProviderConfig(Schema):
     log_conversations: bool = True
     """Whether to log conversations"""
 
-    log_tool_calls: bool = True
-    """Whether to log tool calls"""
-
     log_commands: bool = True
     """Whether to log command executions"""
 
@@ -63,12 +66,29 @@ class SQLStorageConfig(BaseStorageProviderConfig):
     url: str = Field(default_factory=get_database_path)
     """Database URL (e.g. sqlite:///history.db)"""
 
-    pool_size: int = 5
+    pool_size: int = Field(default=5, ge=1)
     """Connection pool size"""
 
     auto_migration: bool = True
     """Whether to automatically add missing columns"""
 
+    def get_engine(self) -> AsyncEngine:
+        from sqlalchemy.ext.asyncio import create_async_engine
+
+        # Convert URL to async format
+        url_str = str(self.url)
+        if url_str.startswith("sqlite://"):
+            url_str = url_str.replace("sqlite://", "sqlite+aiosqlite://", 1)
+        elif url_str.startswith("postgresql://"):
+            url_str = url_str.replace("postgresql://", "postgresql+asyncpg://", 1)
+        elif url_str.startswith("mysql://"):
+            url_str = url_str.replace("mysql://", "mysql+aiomysql://", 1)
+
+        # SQLite doesn't support pool_size parameter
+        if url_str.startswith("sqlite+aiosqlite://"):
+            return create_async_engine(url_str)
+        return create_async_engine(url_str, pool_size=self.pool_size)
+
 
 class TextLogConfig(BaseStorageProviderConfig):
     """Text log configuration."""
@@ -122,7 +142,7 @@ class Mem0Config(BaseStorageProviderConfig):
     api_key: SecretStr | None = None
     """API key for mem0 service."""
 
-    page_size: int = 100
+    page_size: int = Field(default=100, ge=1)
     """Number of results per page when retrieving paginated data."""
 
     output_format: Literal["v1.0", "v1.1"] = "v1.1"
@@ -164,9 +184,6 @@ class StorageConfig(Schema):
     log_conversations: bool = True
     """Whether to log conversations."""
 
-    log_tool_calls: bool = True
-    """Whether to log tool calls."""
-
     log_commands: bool = True
     """Whether to log command executions."""
 
