@@ -7,7 +7,7 @@ from typing import TYPE_CHECKING, Any
 
 
 if TYPE_CHECKING:
-    from collections.abc import AsyncIterator, Coroutine
+    from collections.abc import Coroutine
 
     from mcp import types
     from pydantic import BaseModel
@@ -20,14 +20,11 @@ if TYPE_CHECKING:
 class InputProvider(ABC):
     """Base class for handling all UI interactions."""
 
-    def __init__(self, real_streaming: bool = False):
-        self.real_streaming = real_streaming
-
     async def get_input(
         self,
         context: AgentContext,
         prompt: str,
-        result_type: type | None = None,
+        output_type: type | None = None,
         message_history: list[ChatMessage] | None = None,
     ) -> Any:
         """Get normal input (used by HumanProvider).
@@ -35,12 +32,12 @@ class InputProvider(ABC):
         Args:
             context: Current agent context
             prompt: The prompt to show to the user
-            result_type: Optional type for structured responses
+            output_type: Optional type for structured responses
             message_history: Optional conversation history
         """
-        if result_type:
+        if output_type:
             return await self.get_structured_input(
-                context, prompt, result_type, message_history
+                context, prompt, output_type, message_history
             )
         return await self.get_text_input(context, prompt, message_history)
 
@@ -57,40 +54,12 @@ class InputProvider(ABC):
         self,
         context: AgentContext[Any],
         prompt: str,
-        result_type: type[BaseModel],
+        output_type: type[BaseModel],
         message_history: list[ChatMessage] | None = None,
     ) -> BaseModel:
         """Get structured input, with promptantic and fallback handling."""
         raise NotImplementedError
 
-    async def get_streaming_input(
-        self,
-        context: AgentContext[Any],
-        prompt: str,
-        result_type: type | None = None,
-        message_history: list[ChatMessage] | None = None,
-    ) -> AsyncIterator[str]:
-        """Public interface that handles streaming decision."""
-        if self.real_streaming:
-            async for chunk in self._get_streaming_input(
-                context, prompt, result_type, message_history
-            ):
-                yield chunk
-        else:
-            response = await self.get_input(context, prompt, result_type, message_history)
-            yield response
-
-    async def _get_streaming_input(
-        self,
-        context: AgentContext[Any],
-        prompt: str,
-        result_type: type | None = None,
-        message_history: list[ChatMessage] | None = None,
-    ) -> AsyncIterator[str]:
-        """Default implementation for real streaming."""
-        response = await self.get_input(context, prompt, result_type, message_history)
-        yield response
-
     @abstractmethod
     def get_tool_confirmation(
         self,
