@@ -11,7 +11,7 @@ from typing import (
 )
 
 from psygnal import Signal
-from pydantic_ai import _agent_graph
+from pydantic_ai import ModelResponse, _agent_graph
 from pydantic_ai.result import FinalResult
 from pydantic_graph import End
 
@@ -23,9 +23,10 @@ if TYPE_CHECKING:
     from collections.abc import AsyncIterator
 
     from pydantic_ai import AgentRunResultEvent, AgentStreamEvent
+    from pydantic_ai.models import Model
 
     from llmling_agent.agent.context import AgentContext
-    from llmling_agent.common_types import ModelProtocol, ModelType
+    from llmling_agent.common_types import ModelType
     from llmling_agent.messaging.messages import ChatMessage, TokenCost
     from llmling_agent.models.content import Content
     from llmling_agent.tools.base import Tool
@@ -42,9 +43,9 @@ class ProviderResponse:
 
     content: Any
     tool_calls: list[ToolCallInfo] = field(default_factory=list)
-    model_name: str = ""
+    response: ModelResponse = field(default_factory=lambda: ModelResponse(parts=[]))
     cost_and_usage: TokenCost | None = None
-    provider_extra: dict[str, Any] | None = None
+    provider_details: dict[str, Any] | None = None
 
 
 @dataclass
@@ -71,7 +72,6 @@ class AgentProvider[TDeps]:
     """Base class for agent providers."""
 
     tool_used = Signal(ToolCallInfo)
-    model_changed = Signal(object)  # Model | None
     NAME: str
 
     def __init__(
@@ -83,7 +83,7 @@ class AgentProvider[TDeps]:
     ):
         super().__init__()
         self._name = name
-        self._model: str | ModelProtocol | None = None
+        self._model: str | Model | None = None
         self._context = context
         self._debug = debug
 
@@ -126,7 +126,7 @@ class AgentProvider[TDeps]:
         *prompts: str | Content,
         message_id: str,
         message_history: list[ChatMessage],
-        result_type: type[Any] | None = None,
+        output_type: type[Any] | None = None,
         model: ModelType = None,
         tools: list[Tool] | None = None,
         usage_limits: UsageLimits | None = None,
@@ -135,17 +135,17 @@ class AgentProvider[TDeps]:
         """Generate a response. Must be implemented by providers."""
         raise NotImplementedError
 
-    def stream_events(
+    def stream_events[TResult](
         self,
         *prompts: str | Content,
         message_id: str,
         message_history: list[ChatMessage],
-        result_type: type[Any] | None = None,
+        output_type: type[TResult] | None = None,
         model: ModelType = None,
         tools: list[Tool] | None = None,
         usage_limits: UsageLimits | None = None,
         **kwargs: Any,
-    ) -> AsyncIterator[AgentStreamEvent | AgentRunResultEvent]:
+    ) -> AsyncIterator[AgentStreamEvent | AgentRunResultEvent[TResult]]:
         """Stream a response. Must be implemented by providers."""
         raise NotImplementedError
 
