@@ -14,6 +14,7 @@ from pydantic_ai import (
     FunctionToolCallEvent,
     PartStartEvent,
     RunContext,
+    RunUsage,
     TextPartDelta,
     ToolCallPart,
     UsageLimits as PydanticAiUsageLimits,
@@ -24,7 +25,7 @@ from pydantic_ai.tools import GenerateToolJsonSchema
 
 from llmling_agent.agent.context import AgentContext
 from llmling_agent.log import get_logger
-from llmling_agent.messaging.messages import TokenCost, TokenUsage
+from llmling_agent.messaging.messages import TokenCost
 from llmling_agent.tasks.exceptions import (
     ChainAbortedError,
     RunAbortedError,
@@ -35,7 +36,6 @@ from llmling_agent_providers.base import AgentProvider, ProviderResponse
 from llmling_agent_providers.pydanticai.utils import (
     convert_prompts_to_user_content,
     get_tool_calls,
-    to_model_request,
 )
 
 
@@ -309,7 +309,7 @@ class PydanticAIProvider(AgentProvider[Any]):
         result: AgentRunResult = await agent.run(
             converted_prompts,  # Pass converted prompts
             deps=self._context,  # type: ignore
-            message_history=[to_model_request(m) for m in message_history],
+            message_history=[m.to_pydantic_ai() for m in message_history],
             model=to_use,
             output_type=output_type or str,
             model_settings=self.model_settings,  # type: ignore
@@ -329,10 +329,9 @@ class PydanticAIProvider(AgentProvider[Any]):
         usage = result.usage()
         cost = await TokenCost.from_usage(model=resolved_model, usage=usage)
         total = cost.total_cost if cost else Decimal(0)
-        token_usage = TokenUsage(
-            total=usage.total_tokens,
-            prompt=usage.input_tokens,
-            completion=usage.output_tokens,
+        token_usage = RunUsage(
+            input_tokens=usage.input_tokens,
+            output_tokens=usage.output_tokens,
         )
         cost_info = TokenCost(token_usage=token_usage, total_cost=total)
         return ProviderResponse(
@@ -363,7 +362,7 @@ class PydanticAIProvider(AgentProvider[Any]):
             model = infer_model(model)
         self._model = model
         self._kwargs["model"] = model
-        logger.debug("Changed model from %s to %s", old_name, self.model_name)
+        logger.debug("Changed model", old_name=old_name, new_name=self.model_name)
 
     @property
     def model_name(self) -> str | None:
@@ -419,7 +418,7 @@ class PydanticAIProvider(AgentProvider[Any]):
         async for event in agent.run_stream_events(
             converted_prompts,
             deps=self._context,
-            message_history=[to_model_request(m) for m in message_history],
+            message_history=[m.to_pydantic_ai() for m in message_history],
             model=model or self.model,  # type: ignore
             output_type=output_type or str,
             model_settings=self.model_settings,  # type: ignore
